@@ -22,7 +22,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Canon;
 
-$VERSION = '1.25';
+$VERSION = '1.27';
 
 sub ProcessCanonVRD($$;$);
 sub WriteCanonVRD($$;$);
@@ -1331,26 +1331,38 @@ my $blankFooter = "CANON OPTIONAL DATA\0" . ("\0" x 42) . "\xff\xd9";
     # 0x0b - value: 14
     0x0c => {
         Name => 'GammaBlackPoint',
-        ValueConv => '$val > 0 ? log($val / 4.6875) / log(2) + 1 : 0',
+        ValueConv => q{
+            return 0 if $val <= 0;
+            $val = log($val / 4.6875) / log(2) + 1;
+            return abs($val) > 1e-10 ? $val : 0;
+        },
         ValueConvInv => '$val ? exp(($val - 1) * log(2)) * 4.6876 : 0',
         PrintConv => 'sprintf("%+.3f", $val)',
         PrintConvInv => '$val',
     },
     0x0d => {
-        Name => 'GammeWhitePoint',
-        ValueConv => '$val > 0 ? log($val / 4.6875) / log(2) - 11.77109325169954 : $val',
+        Name => 'GammaWhitePoint',
+        ValueConv => q{
+            return $val if $val <= 0;
+            $val = log($val / 4.6875) / log(2) - 11.77109325169954;
+            return abs($val) > 1e-10 ? $val : 0;
+        },
         ValueConvInv => '$val ? exp(($val + 11.77109325169954) * log(2)) * 4.6875 : 0',
         PrintConv => 'sprintf("%+.3f", $val)',
         PrintConvInv => '$val',
     },
     0x0e => {
         Name => 'GammaMidPoint',
-        ValueConv => '$val > 0 ? log($val / 4.6875) / log(2) - 8 : $val',
+        ValueConv => q{
+            return $val if $val <= 0;
+            $val = log($val / 4.6875) / log(2) - 8;
+            return abs($val) > 1e-10 ? $val : 0;
+        },
         ValueConvInv => '$val ? exp(($val + 8) * log(2)) * 4.6876 : 0',
         PrintConv => 'sprintf("%+.3f", $val)',
         PrintConvInv => '$val',
     },
-    0x0f => { Name => 'GammaCurveOutputRange', Format => 'double[2]', Notes => '16393 max' },
+    0x0f => { Name => 'GammaCurveOutputRange', Format => 'double[2]', Notes => '16383 max' },
 );
 
 # Version 4 crop information (ref PH)
@@ -1686,7 +1698,7 @@ sub ProcessDR4($$;$)
     # write CanonDR4 as a block if specified
     if ($isWriting) {
         my $nvHash;
-        my $newVal = $et->GetNewValues('CanonDR4', \$nvHash);
+        my $newVal = $et->GetNewValue('CanonDR4', \$nvHash);
         if ($newVal) {
             $et->VPrint(0, "  Writing CanonDR4 as a block\n");
             $$et{DidCanonVRD} = 1;  # set flag so we don't add this twice
@@ -1813,7 +1825,7 @@ sub ProcessDR4($$;$)
                     }
                     $val = ReadValue($dataPt, $off, $format, undef, $len) unless defined $val;
                     my $nvHash;
-                    my $newVal = $et->GetNewValues($tagInfo, \$nvHash);
+                    my $newVal = $et->GetNewValue($tagInfo, \$nvHash);
                     if ($et->IsOverwriting($nvHash, $val) and defined $newVal) {
                         my $count = int($len / Image::ExifTool::FormatSize($format));
                         my $rtnVal = WriteValue($newVal, $format, $count, $dataPt, $off);
@@ -1866,7 +1878,7 @@ sub ProcessVRD($$)
 
     if (not $num and $$dirInfo{OutFile}) {
         # create new VRD file from scratch
-        my $newVal = $et->GetNewValues('CanonVRD');
+        my $newVal = $et->GetNewValue('CanonVRD');
         if ($newVal) {
             $et->VPrint(0, "  Writing CanonVRD as a block\n");
             Write($$dirInfo{OutFile}, $newVal) or return -1;
@@ -1906,7 +1918,7 @@ sub WriteCanonVRD($$;$)
     my ($et, $dirInfo, $tagTablePtr) = @_;
     $et or return 1;    # allow dummy access
     my $nvHash = $et->GetNewValueHash($Image::ExifTool::Extra{CanonVRD});
-    my $val = $et->GetNewValues($nvHash);
+    my $val = $et->GetNewValue($nvHash);
     $val = '' unless defined $val;
     return undef unless $et->IsOverwriting($nvHash, $val);
     ++$$et{CHANGED};
@@ -1942,7 +1954,7 @@ sub ProcessCanonVRD($$;$)
             # create blank VRD data from scratch
             my $blank = $blankHeader . $blankFooter;
             $dataPt = \$blank;
-            $verbose and printf $out "  Creating CanonVRD trailer\n";
+            $verbose and print $out "  Creating CanonVRD trailer\n";
             $created = 1;
         }
         $raf = new File::RandomAccess($dataPt);
@@ -1993,7 +2005,7 @@ sub ProcessCanonVRD($$;$)
     my $vrdType = 'VRD';
 
     if ($outfile) {
-        $verbose and not $created and printf $out "  Rewriting CanonVRD trailer\n";
+        $verbose and not $created and print $out "  Rewriting CanonVRD trailer\n";
         # delete CanonVRD information if specified
         my $doDel = $$et{DEL_GROUP}{CanonVRD};
         unless ($doDel) {
@@ -2012,9 +2024,9 @@ sub ProcessCanonVRD($$;$)
         }
         if ($doDel) {
             if ($$et{FILE_TYPE} eq 'VRD') {
-                my $newVal = $et->GetNewValues('CanonVRD');
+                my $newVal = $et->GetNewValue('CanonVRD');
                 if ($newVal) {
-                    $verbose and printf $out "  Writing CanonVRD as a block\n";
+                    $verbose and print $out "  Writing CanonVRD as a block\n";
                     if ($outfile eq $dataPt) {
                         $$outfile = $newVal;
                     } else {
@@ -2026,16 +2038,16 @@ sub ProcessCanonVRD($$;$)
                     $et->Error("Can't delete all CanonVRD information from a VRD file");
                 }
             } else {
-                $verbose and printf $out "  Deleting CanonVRD trailer\n";
+                $verbose and print $out "  Deleting CanonVRD trailer\n";
                 $$outfile = '' if $outfile eq $dataPt;
                 ++$$et{CHANGED};
             }
             return 1;
         }
         # write now and return if CanonVRD was set as a block
-        my $val = $et->GetNewValues('CanonVRD');
+        my $val = $et->GetNewValue('CanonVRD');
         unless ($val) {
-            $val = $et->GetNewValues('CanonDR4');
+            $val = $et->GetNewValue('CanonDR4');
             $vrdType = 'DR4' if $val;
         }
         if ($val) {
@@ -2060,7 +2072,7 @@ sub ProcessCanonVRD($$;$)
     # validate VRD trailer and get position and length of edit record
     SetByteOrder('MM'); # VRD header/footer is big-endian
     my $pos = 0x1c;     # start at end of header
- 
+
     # loop through the VRD blocks
     for (;;) {
         my $end = $dirLen - 0x40;   # end of last VRD block (and start of footer)
@@ -2126,7 +2138,7 @@ sub ProcessCanonVRD($$;$)
                 if ($$et{NEW_VALUE}{$tagInfo}) {
                     # write as a block
                     $et->VPrint(0, "Writing $$tagInfo{Name} as a block\n");
-                    $dat = $et->GetNewValues($tagInfo);
+                    $dat = $et->GetNewValue($tagInfo);
                     $dat = '' unless defined $dat;
                     ++$$et{CHANGED};
                 } else {
@@ -2177,7 +2189,7 @@ sub ProcessCanonVRD($$;$)
         if (length $$dataPt) {
             Write($outfile, $$dataPt) or $err = 1 unless $outfile eq $dataPt;
         } else {
-            $verbose and printf $out "  Deleting CanonVRD trailer\n";
+            $verbose and print $out "  Deleting CanonVRD trailer\n";
         }
     } elsif ($vrdType eq 'VRD' and (($$et{TAGS_FROM_FILE} and
         not $$et{EXCL_TAG_LOOKUP}{canonvrd}) or $$et{REQ_TAG_LOOKUP}{canonvrd}))
